@@ -37,6 +37,9 @@ function(para) {
     else if(type == 'pe3') {
       return(lmompe3(para))
     }
+    else if(type == 'revgum') {
+      return(lmomrevgum(para))
+    }
     else if(type == 'wak') {
       return(lmomwak(para))
     }
